/*--------------------------------------------------------------------------+
$Id: codetemplates.xml 1 2011-01-01 00:00:01Z hoelzl $
|                                                                          |
| Copyright 2017 fortiss GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.af3.platform.raspberry.ui.prototype;

import static org.fortiss.tooling.base.layout.DefaultLayoutConstants.DEFAULT_SHAPE_MINIMUM_HEIGHT;
import static org.fortiss.tooling.base.layout.DefaultLayoutConstants.DEFAULT_SHAPE_MINIMUM_WIDTH;
import static org.fortiss.tooling.base.ui.utils.LayoutDataUIUtils.setConnectorPosition;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.setNodeBounds;
import static org.fortiss.tooling.base.utils.LayoutDataUtils.setNodePosition;
import static org.fortiss.tooling.base.utils.LayoutModelElementFactory.createRectangle;

import org.fortiss.af3.platform.raspberry.model.ActuatorPWM;
import org.fortiss.af3.platform.raspberry.model.CanBus;
import org.fortiss.af3.platform.raspberry.model.CanConnector;
import org.fortiss.af3.platform.raspberry.model.RaspberryPi;
import org.fortiss.af3.platform.raspberry.model.SensorIMU;
import org.fortiss.af3.platform.raspberry.model.SensorLaserRangeFinder;
import org.fortiss.af3.platform.raspberry.model.SensorLaserScanner;
import org.fortiss.af3.platform.raspberry.util.RaspberryModelElementFactory;
import org.fortiss.tooling.kernel.extension.base.PrototypeProviderBase;

/**
 * 
 * @author eder
 * @author $Author: hoelzl $
 * @version $Rev: 18709 $
 * @ConQAT.Rating RED Hash:
 */
public class ProtoypeProvider extends PrototypeProviderBase {

	/** Stores the category to display for these prototypes. */
	protected final static String CATEGORY_NAME = "RaspberryPI Platform";

	/** {@inheritDoc} */
	@Override
	protected void registerPrototypes() {
		RaspberryPi pi = RaspberryModelElementFactory.createRaspberryPi();
		registerPrimaryPrototype("RaspberryPi", pi, CATEGORY_NAME);

		CanBus bus = RaspberryModelElementFactory.createCanBus();
		setNodeBounds(bus,
				createRectangle(0, 0, DEFAULT_SHAPE_MINIMUM_WIDTH, DEFAULT_SHAPE_MINIMUM_HEIGHT));
		registerPrototype("CanBus", bus, CATEGORY_NAME);

		CanConnector con = RaspberryModelElementFactory.createCanConnector();
		setNodePosition(con, 0, 0);
		setConnectorPosition(con, 0, 0);
		registerPrototype("CanConnector", con, CATEGORY_NAME);

		// SensorConnector sensor = RaspberryModelElementFactory.createSensorConnector();
		// setNodePosition(sensor, 0, 0);
		// setConnectorPosition(sensor, 0, 0);
		// registerPrototype("GenericPI_Sensor", sensor, CATEGORY_NAME);

		SensorIMU imu = RaspberryModelElementFactory.createSensorIMU();
		setNodePosition(imu, 0, 0);
		setConnectorPosition(imu, 0, 0);
		registerPrototype("IMU_Sensor", imu, CATEGORY_NAME);

		SensorLaserRangeFinder slrf = RaspberryModelElementFactory.createSensorLaserRangeFinder();
		setNodePosition(slrf, 0, 0);
		setConnectorPosition(slrf, 0, 0);
		registerPrototype("LaserRangeFinder_Sensor", slrf, CATEGORY_NAME);

		SensorLaserScanner sls = RaspberryModelElementFactory.createSensorLaserScanner();
		setNodePosition(sls, 0, 0);
		setConnectorPosition(sls, 0, 0);
		registerPrototype("LaserScanner_Sensor", sls, CATEGORY_NAME);

		// ActuatorConnector actuator = RaspberryModelElementFactory.createActuatorConnector();
		// setNodePosition(actuator, 0, 0);
		// setConnectorPosition(actuator, 0, 0);
		// registerPrototype("GenericPI_Actuator", actuator, CATEGORY_NAME);

		ActuatorPWM pwm = RaspberryModelElementFactory.createActuatorPWM();
		setNodePosition(pwm, 0, 0);
		setConnectorPosition(pwm, 0, 0);
		registerPrototype("PWM_Actuator", pwm, CATEGORY_NAME);

	}
}
